@@ -1,9 +1,12 @@
+import os
+
 import numpy as np
 import pandas as pd
-import os
+
 from mksc.core import reader
 
-def load_data(mode='all', local=True):
+
+def load_data(settings, mode='all', local=True):
     """
     加载配置文件指定数据源，返回数据
     Args:
